@@ -2,7 +2,7 @@
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 19/09/2010 20:32:59
+# Update    : 02/12/2010 09:59:00
 # AIM       : Venn diagram example
 #==================================================================
 use warnings;
@@ -15,7 +15,7 @@ use Venn::Chart;
 my $VennChart = new Venn::Chart( 400, 400 ) or die("error : $!");
 
 # Set a title and a legend for our chart
-$VennChart->set( -title => 'Venn Diagram' );
+$VennChart->set( -title => 'Venn diagram' );
 $VennChart->set_legends( 'Team 1', 'Team 2', 'Team 3' );
 
 # 3 lists for the Venn diagram
@@ -32,9 +32,17 @@ binmode $fh_venn;
 print {$fh_venn} $gd_venn->png;
 close($fh_venn);
 
-# Create an histogram image of Venn diagram (png, gif and jpeg format).
+# Create an histogram image of Venn diagram (png, gif and jpeg format)
 my $gd_histogram = $VennChart->plot_histogram;
 open( my $fh_histo, '>', "VennHistogram.png" );
 binmode $fh_histo;
 print {$fh_histo} $gd_histogram->png;
-close($fh_histo);
\ No newline at end of file
+close($fh_histo);
+
+# Get data list for each intersection or unique region between the 3 lists
+my @ref_lists = $VennChart->get_list_regions();
+my $list_number = 1;
+foreach my $ref_region ( @ref_lists ) {
+  print "List $list_number : @{ $ref_region }\n";
+  $list_number++;
+}
